@@ -1,4 +1,4 @@
-from pokeman.pokeman_o import Pokeman
+from pokeman.pokeman import Pokeman
 from pokeman.amqp_resources.globals import Exchange, RoutingKey, Queue
 from pokeman.amqp_resources import heapq
 from pokeman import amqp_resources
@@ -7,7 +7,7 @@ from pokeman.coatings import BasicMessage, BasicMessageConsumer, PollingConsumer
 
 
 
-__version__ = '0.1.11'
+__version__ = '0.1.12'
 
 
 __all__ = [
